# anonfiles.py
Simple AnonFiles.com API Wrapper written on Python3

## Install

    $ pip3 install anonfiles-py

## Usage
```python3
from anonfiles import AnonFiles

a = AnonFiles()

up = a.upload("example.py")

print(up.status)
```


##
### &copy; 2021 TheBoringDude